# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v5___common___custom_parameter_pb2___CustomParameter,
)
from google.ads.google_ads.v5.proto.common.feed_common_pb2 import (
    Money as google___ads___googleads___v5___common___feed_common_pb2___Money,
)
from google.ads.google_ads.v5.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v5___common___policy_pb2___PolicyTopicEntry,
)
from google.ads.google_ads.v5.proto.enums.feed_item_quality_approval_status_pb2 import (
    FeedItemQualityApprovalStatusEnum as google___ads___googleads___v5___enums___feed_item_quality_approval_status_pb2___FeedItemQualityApprovalStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.feed_item_quality_disapproval_reason_pb2 import (
    FeedItemQualityDisapprovalReasonEnum as google___ads___googleads___v5___enums___feed_item_quality_disapproval_reason_pb2___FeedItemQualityDisapprovalReasonEnum,
)
from google.ads.google_ads.v5.proto.enums.feed_item_status_pb2 import (
    FeedItemStatusEnum as google___ads___googleads___v5___enums___feed_item_status_pb2___FeedItemStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.feed_item_validation_status_pb2 import (
    FeedItemValidationStatusEnum as google___ads___googleads___v5___enums___feed_item_validation_status_pb2___FeedItemValidationStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.geo_targeting_restriction_pb2 import (
    GeoTargetingRestrictionEnum as google___ads___googleads___v5___enums___geo_targeting_restriction_pb2___GeoTargetingRestrictionEnum,
)
from google.ads.google_ads.v5.proto.enums.placeholder_type_pb2 import (
    PlaceholderTypeEnum as google___ads___googleads___v5___enums___placeholder_type_pb2___PlaceholderTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.policy_approval_status_pb2 import (
    PolicyApprovalStatusEnum as google___ads___googleads___v5___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.policy_review_status_pb2 import (
    PolicyReviewStatusEnum as google___ads___googleads___v5___enums___policy_review_status_pb2___PolicyReviewStatusEnum,
)
from google.ads.google_ads.v5.proto.errors.feed_item_validation_error_pb2 import (
    FeedItemValidationErrorEnum as google___ads___googleads___v5___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItem(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    geo_targeting_restriction: google___ads___googleads___v5___enums___geo_targeting_restriction_pb2___GeoTargetingRestrictionEnum.GeoTargetingRestrictionValue = ...
    status: google___ads___googleads___v5___enums___feed_item_status_pb2___FeedItemStatusEnum.FeedItemStatusValue = ...
    @property
    def feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def end_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def attribute_values(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___FeedItemAttributeValue
    ]: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v5___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def policy_infos(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___FeedItemPlaceholderPolicyInfo
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        feed: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        start_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        end_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        attribute_values: typing___Optional[
            typing___Iterable[type___FeedItemAttributeValue]
        ] = None,
        geo_targeting_restriction: typing___Optional[
            google___ads___googleads___v5___enums___geo_targeting_restriction_pb2___GeoTargetingRestrictionEnum.GeoTargetingRestrictionValue
        ] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___feed_item_status_pb2___FeedItemStatusEnum.FeedItemStatusValue
        ] = None,
        policy_infos: typing___Optional[
            typing___Iterable[type___FeedItemPlaceholderPolicyInfo]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "end_date_time",
            b"end_date_time",
            "feed",
            b"feed",
            "id",
            b"id",
            "start_date_time",
            b"start_date_time",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "attribute_values",
            b"attribute_values",
            "end_date_time",
            b"end_date_time",
            "feed",
            b"feed",
            "geo_targeting_restriction",
            b"geo_targeting_restriction",
            "id",
            b"id",
            "policy_infos",
            b"policy_infos",
            "resource_name",
            b"resource_name",
            "start_date_time",
            b"start_date_time",
            "status",
            b"status",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...

type___FeedItem = FeedItem

class FeedItemAttributeValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def feed_attribute_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def integer_value(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def boolean_value(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def string_value(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def double_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def price_value(
        self,
    ) -> google___ads___googleads___v5___common___feed_common_pb2___Money: ...
    @property
    def integer_values(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___Int64Value
    ]: ...
    @property
    def boolean_values(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___BoolValue
    ]: ...
    @property
    def string_values(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def double_values(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___DoubleValue
    ]: ...
    def __init__(
        self,
        *,
        feed_attribute_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        integer_value: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        boolean_value: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        string_value: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        double_value: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        price_value: typing___Optional[
            google___ads___googleads___v5___common___feed_common_pb2___Money
        ] = None,
        integer_values: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___Int64Value]
        ] = None,
        boolean_values: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___BoolValue]
        ] = None,
        string_values: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        double_values: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___DoubleValue]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "boolean_value",
            b"boolean_value",
            "double_value",
            b"double_value",
            "feed_attribute_id",
            b"feed_attribute_id",
            "integer_value",
            b"integer_value",
            "price_value",
            b"price_value",
            "string_value",
            b"string_value",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "boolean_value",
            b"boolean_value",
            "boolean_values",
            b"boolean_values",
            "double_value",
            b"double_value",
            "double_values",
            b"double_values",
            "feed_attribute_id",
            b"feed_attribute_id",
            "integer_value",
            b"integer_value",
            "integer_values",
            b"integer_values",
            "price_value",
            b"price_value",
            "string_value",
            b"string_value",
            "string_values",
            b"string_values",
        ],
    ) -> None: ...

type___FeedItemAttributeValue = FeedItemAttributeValue

class FeedItemPlaceholderPolicyInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    placeholder_type_enum: google___ads___googleads___v5___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue = ...
    review_status: google___ads___googleads___v5___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue = ...
    approval_status: google___ads___googleads___v5___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue = ...
    validation_status: google___ads___googleads___v5___enums___feed_item_validation_status_pb2___FeedItemValidationStatusEnum.FeedItemValidationStatusValue = ...
    quality_approval_status: google___ads___googleads___v5___enums___feed_item_quality_approval_status_pb2___FeedItemQualityApprovalStatusEnum.FeedItemQualityApprovalStatusValue = ...
    quality_disapproval_reasons: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        google___ads___googleads___v5___enums___feed_item_quality_disapproval_reason_pb2___FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue
    ] = ...
    @property
    def feed_mapping_resource_name(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def policy_topic_entries(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v5___common___policy_pb2___PolicyTopicEntry
    ]: ...
    @property
    def validation_errors(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___FeedItemValidationError
    ]: ...
    def __init__(
        self,
        *,
        placeholder_type_enum: typing___Optional[
            google___ads___googleads___v5___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue
        ] = None,
        feed_mapping_resource_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        review_status: typing___Optional[
            google___ads___googleads___v5___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue
        ] = None,
        approval_status: typing___Optional[
            google___ads___googleads___v5___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue
        ] = None,
        policy_topic_entries: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___common___policy_pb2___PolicyTopicEntry
            ]
        ] = None,
        validation_status: typing___Optional[
            google___ads___googleads___v5___enums___feed_item_validation_status_pb2___FeedItemValidationStatusEnum.FeedItemValidationStatusValue
        ] = None,
        validation_errors: typing___Optional[
            typing___Iterable[type___FeedItemValidationError]
        ] = None,
        quality_approval_status: typing___Optional[
            google___ads___googleads___v5___enums___feed_item_quality_approval_status_pb2___FeedItemQualityApprovalStatusEnum.FeedItemQualityApprovalStatusValue
        ] = None,
        quality_disapproval_reasons: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___enums___feed_item_quality_disapproval_reason_pb2___FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReasonValue
            ]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "feed_mapping_resource_name", b"feed_mapping_resource_name"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "approval_status",
            b"approval_status",
            "feed_mapping_resource_name",
            b"feed_mapping_resource_name",
            "placeholder_type_enum",
            b"placeholder_type_enum",
            "policy_topic_entries",
            b"policy_topic_entries",
            "quality_approval_status",
            b"quality_approval_status",
            "quality_disapproval_reasons",
            b"quality_disapproval_reasons",
            "review_status",
            b"review_status",
            "validation_errors",
            b"validation_errors",
            "validation_status",
            b"validation_status",
        ],
    ) -> None: ...

type___FeedItemPlaceholderPolicyInfo = FeedItemPlaceholderPolicyInfo

class FeedItemValidationError(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    validation_error: google___ads___googleads___v5___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum.FeedItemValidationErrorValue = ...
    @property
    def description(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def feed_attribute_ids(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___Int64Value
    ]: ...
    @property
    def extra_info(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        validation_error: typing___Optional[
            google___ads___googleads___v5___errors___feed_item_validation_error_pb2___FeedItemValidationErrorEnum.FeedItemValidationErrorValue
        ] = None,
        description: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        feed_attribute_ids: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___Int64Value]
        ] = None,
        extra_info: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "description", b"description", "extra_info", b"extra_info"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "description",
            b"description",
            "extra_info",
            b"extra_info",
            "feed_attribute_ids",
            b"feed_attribute_ids",
            "validation_error",
            b"validation_error",
        ],
    ) -> None: ...

type___FeedItemValidationError = FeedItemValidationError



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.common.tag_snippet_pb2 import (
    TagSnippet as google___ads___googleads___v4___common___tag_snippet_pb2___TagSnippet,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class RemarketingAction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def tag_snippets(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v4___common___tag_snippet_pb2___TagSnippet
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        tag_snippets: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v4___common___tag_snippet_pb2___TagSnippet
            ]
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["id", b"id", "name", b"name"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "id",
            b"id",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "tag_snippets",
            b"tag_snippets",
        ],
    ) -> None: ...

type___RemarketingAction = RemarketingAction



from typing import Any

class CampaignExtensionSettingServiceStub:
    GetCampaignExtensionSetting: Any = ...
    MutateCampaignExtensionSettings: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignExtensionSettingServiceServicer:
    def GetCampaignExtensionSetting(self, request: Any, context: Any) -> None: ...
    def MutateCampaignExtensionSettings(self, request: Any, context: Any) -> None: ...

def add_CampaignExtensionSettingServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PromotionPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PromotionPlaceholderFieldValue = typing___NewType(
        "PromotionPlaceholderFieldValue", builtin___int
    )
    type___PromotionPlaceholderFieldValue = PromotionPlaceholderFieldValue
    PromotionPlaceholderField: _PromotionPlaceholderField
    class _PromotionPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 1
        )
        PROMOTION_TARGET = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 2
        )
        DISCOUNT_MODIFIER = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 3
        )
        PERCENT_OFF = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 4
        )
        MONEY_AMOUNT_OFF = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 5
        )
        PROMOTION_CODE = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 6
        )
        ORDERS_OVER_AMOUNT = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 7
        )
        PROMOTION_START = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 8
        )
        PROMOTION_END = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 9
        )
        OCCASION = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 10
        )
        FINAL_URLS = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 11
        )
        FINAL_MOBILE_URLS = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 12
        )
        TRACKING_URL = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 13
        )
        LANGUAGE = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 14
        )
        FINAL_URL_SUFFIX = typing___cast(
            PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 15
        )
    UNSPECIFIED = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 1
    )
    PROMOTION_TARGET = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 2
    )
    DISCOUNT_MODIFIER = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 3
    )
    PERCENT_OFF = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 4
    )
    MONEY_AMOUNT_OFF = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 5
    )
    PROMOTION_CODE = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 6
    )
    ORDERS_OVER_AMOUNT = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 7
    )
    PROMOTION_START = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 8
    )
    PROMOTION_END = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 9
    )
    OCCASION = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 10
    )
    FINAL_URLS = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 11
    )
    FINAL_MOBILE_URLS = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 12
    )
    TRACKING_URL = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 13
    )
    LANGUAGE = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 14
    )
    FINAL_URL_SUFFIX = typing___cast(
        PromotionPlaceholderFieldEnum.PromotionPlaceholderFieldValue, 15
    )
    type___PromotionPlaceholderField = PromotionPlaceholderField
    def __init__(self,) -> None: ...

type___PromotionPlaceholderFieldEnum = PromotionPlaceholderFieldEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.asset_field_type_pb2 import (
    AssetFieldTypeEnum as google___ads___googleads___v5___enums___asset_field_type_pb2___AssetFieldTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.asset_link_status_pb2 import (
    AssetLinkStatusEnum as google___ads___googleads___v5___enums___asset_link_status_pb2___AssetLinkStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    campaign: typing___Text = ...
    asset: typing___Text = ...
    field_type: google___ads___googleads___v5___enums___asset_field_type_pb2___AssetFieldTypeEnum.AssetFieldTypeValue = ...
    status: google___ads___googleads___v5___enums___asset_link_status_pb2___AssetLinkStatusEnum.AssetLinkStatusValue = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        campaign: typing___Optional[typing___Text] = None,
        asset: typing___Optional[typing___Text] = None,
        field_type: typing___Optional[
            google___ads___googleads___v5___enums___asset_field_type_pb2___AssetFieldTypeEnum.AssetFieldTypeValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___asset_link_status_pb2___AssetLinkStatusEnum.AssetLinkStatusValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_asset",
            b"_asset",
            "_campaign",
            b"_campaign",
            "asset",
            b"asset",
            "campaign",
            b"campaign",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_asset",
            b"_asset",
            "_campaign",
            b"_campaign",
            "asset",
            b"asset",
            "campaign",
            b"campaign",
            "field_type",
            b"field_type",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_asset", b"_asset"]
    ) -> typing_extensions___Literal["asset"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_campaign", b"_campaign"]
    ) -> typing_extensions___Literal["campaign"]: ...

type___CampaignAsset = CampaignAsset



from typing import Any

class LocationViewServiceStub:
    GetLocationView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class LocationViewServiceServicer:
    def GetLocationView(self, request: Any, context: Any) -> None: ...

def add_LocationViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class TravelPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    TravelPlaceholderFieldValue = typing___NewType(
        "TravelPlaceholderFieldValue", builtin___int
    )
    type___TravelPlaceholderFieldValue = TravelPlaceholderFieldValue
    TravelPlaceholderField: _TravelPlaceholderField
    class _TravelPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 1
        )
        DESTINATION_ID = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 2
        )
        ORIGIN_ID = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 3
        )
        TITLE = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 4)
        DESTINATION_NAME = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 5
        )
        ORIGIN_NAME = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 6
        )
        PRICE = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 7)
        FORMATTED_PRICE = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 8
        )
        SALE_PRICE = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 9
        )
        FORMATTED_SALE_PRICE = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 10
        )
        IMAGE_URL = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 11
        )
        CATEGORY = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 12
        )
        CONTEXTUAL_KEYWORDS = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 13
        )
        DESTINATION_ADDRESS = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 14
        )
        FINAL_URL = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 15
        )
        FINAL_MOBILE_URLS = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 16
        )
        TRACKING_URL = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 17
        )
        ANDROID_APP_LINK = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 18
        )
        SIMILAR_DESTINATION_IDS = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 19
        )
        IOS_APP_LINK = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 20
        )
        IOS_APP_STORE_ID = typing___cast(
            TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 21
        )
    UNSPECIFIED = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 1)
    DESTINATION_ID = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 2
    )
    ORIGIN_ID = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 3)
    TITLE = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 4)
    DESTINATION_NAME = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 5
    )
    ORIGIN_NAME = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 6
    )
    PRICE = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 7)
    FORMATTED_PRICE = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 8
    )
    SALE_PRICE = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 9
    )
    FORMATTED_SALE_PRICE = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 10
    )
    IMAGE_URL = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 11
    )
    CATEGORY = typing___cast(TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 12)
    CONTEXTUAL_KEYWORDS = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 13
    )
    DESTINATION_ADDRESS = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 14
    )
    FINAL_URL = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 15
    )
    FINAL_MOBILE_URLS = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 16
    )
    TRACKING_URL = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 17
    )
    ANDROID_APP_LINK = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 18
    )
    SIMILAR_DESTINATION_IDS = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 19
    )
    IOS_APP_LINK = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 20
    )
    IOS_APP_STORE_ID = typing___cast(
        TravelPlaceholderFieldEnum.TravelPlaceholderFieldValue, 21
    )
    type___TravelPlaceholderField = TravelPlaceholderField
    def __init__(self,) -> None: ...

type___TravelPlaceholderFieldEnum = TravelPlaceholderFieldEnum



from typing import Any

class FeedItemTargetServiceStub:
    GetFeedItemTarget: Any = ...
    MutateFeedItemTargets: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedItemTargetServiceServicer:
    def GetFeedItemTarget(self, request: Any, context: Any) -> None: ...
    def MutateFeedItemTargets(self, request: Any, context: Any) -> None: ...

def add_FeedItemTargetServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.customer_pay_per_conversion_eligibility_failure_reason_pb2 import (
    CustomerPayPerConversionEligibilityFailureReasonEnum as google___ads___googleads___v5___enums___customer_pay_per_conversion_eligibility_failure_reason_pb2___CustomerPayPerConversionEligibilityFailureReasonEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Customer(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    descriptive_name: typing___Text = ...
    currency_code: typing___Text = ...
    time_zone: typing___Text = ...
    tracking_url_template: typing___Text = ...
    final_url_suffix: typing___Text = ...
    auto_tagging_enabled: builtin___bool = ...
    has_partners_badge: builtin___bool = ...
    manager: builtin___bool = ...
    test_account: builtin___bool = ...
    pay_per_conversion_eligibility_failure_reasons: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        google___ads___googleads___v5___enums___customer_pay_per_conversion_eligibility_failure_reason_pb2___CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue
    ] = ...
    optimization_score: builtin___float = ...
    @property
    def call_reporting_setting(self) -> type___CallReportingSetting: ...
    @property
    def conversion_tracking_setting(self) -> type___ConversionTrackingSetting: ...
    @property
    def remarketing_setting(self) -> type___RemarketingSetting: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        descriptive_name: typing___Optional[typing___Text] = None,
        currency_code: typing___Optional[typing___Text] = None,
        time_zone: typing___Optional[typing___Text] = None,
        tracking_url_template: typing___Optional[typing___Text] = None,
        final_url_suffix: typing___Optional[typing___Text] = None,
        auto_tagging_enabled: typing___Optional[builtin___bool] = None,
        has_partners_badge: typing___Optional[builtin___bool] = None,
        manager: typing___Optional[builtin___bool] = None,
        test_account: typing___Optional[builtin___bool] = None,
        call_reporting_setting: typing___Optional[type___CallReportingSetting] = None,
        conversion_tracking_setting: typing___Optional[
            type___ConversionTrackingSetting
        ] = None,
        remarketing_setting: typing___Optional[type___RemarketingSetting] = None,
        pay_per_conversion_eligibility_failure_reasons: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___enums___customer_pay_per_conversion_eligibility_failure_reason_pb2___CustomerPayPerConversionEligibilityFailureReasonEnum.CustomerPayPerConversionEligibilityFailureReasonValue
            ]
        ] = None,
        optimization_score: typing___Optional[builtin___float] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_auto_tagging_enabled",
            b"_auto_tagging_enabled",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_has_partners_badge",
            b"_has_partners_badge",
            "_id",
            b"_id",
            "_manager",
            b"_manager",
            "_optimization_score",
            b"_optimization_score",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "_tracking_url_template",
            b"_tracking_url_template",
            "auto_tagging_enabled",
            b"auto_tagging_enabled",
            "call_reporting_setting",
            b"call_reporting_setting",
            "conversion_tracking_setting",
            b"conversion_tracking_setting",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "final_url_suffix",
            b"final_url_suffix",
            "has_partners_badge",
            b"has_partners_badge",
            "id",
            b"id",
            "manager",
            b"manager",
            "optimization_score",
            b"optimization_score",
            "remarketing_setting",
            b"remarketing_setting",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_auto_tagging_enabled",
            b"_auto_tagging_enabled",
            "_currency_code",
            b"_currency_code",
            "_descriptive_name",
            b"_descriptive_name",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_has_partners_badge",
            b"_has_partners_badge",
            "_id",
            b"_id",
            "_manager",
            b"_manager",
            "_optimization_score",
            b"_optimization_score",
            "_test_account",
            b"_test_account",
            "_time_zone",
            b"_time_zone",
            "_tracking_url_template",
            b"_tracking_url_template",
            "auto_tagging_enabled",
            b"auto_tagging_enabled",
            "call_reporting_setting",
            b"call_reporting_setting",
            "conversion_tracking_setting",
            b"conversion_tracking_setting",
            "currency_code",
            b"currency_code",
            "descriptive_name",
            b"descriptive_name",
            "final_url_suffix",
            b"final_url_suffix",
            "has_partners_badge",
            b"has_partners_badge",
            "id",
            b"id",
            "manager",
            b"manager",
            "optimization_score",
            b"optimization_score",
            "pay_per_conversion_eligibility_failure_reasons",
            b"pay_per_conversion_eligibility_failure_reasons",
            "remarketing_setting",
            b"remarketing_setting",
            "resource_name",
            b"resource_name",
            "test_account",
            b"test_account",
            "time_zone",
            b"time_zone",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_auto_tagging_enabled", b"_auto_tagging_enabled"
        ],
    ) -> typing_extensions___Literal["auto_tagging_enabled"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions___Literal["currency_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_descriptive_name", b"_descriptive_name"
        ],
    ) -> typing_extensions___Literal["descriptive_name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_final_url_suffix", b"_final_url_suffix"
        ],
    ) -> typing_extensions___Literal["final_url_suffix"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_has_partners_badge", b"_has_partners_badge"
        ],
    ) -> typing_extensions___Literal["has_partners_badge"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_manager", b"_manager"]
    ) -> typing_extensions___Literal["manager"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_optimization_score", b"_optimization_score"
        ],
    ) -> typing_extensions___Literal["optimization_score"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_test_account", b"_test_account"],
    ) -> typing_extensions___Literal["test_account"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_time_zone", b"_time_zone"]
    ) -> typing_extensions___Literal["time_zone"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions___Literal["tracking_url_template"]: ...

type___Customer = Customer

class CallReportingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    call_reporting_enabled: builtin___bool = ...
    call_conversion_reporting_enabled: builtin___bool = ...
    call_conversion_action: typing___Text = ...
    def __init__(
        self,
        *,
        call_reporting_enabled: typing___Optional[builtin___bool] = None,
        call_conversion_reporting_enabled: typing___Optional[builtin___bool] = None,
        call_conversion_action: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_call_conversion_action",
            b"_call_conversion_action",
            "_call_conversion_reporting_enabled",
            b"_call_conversion_reporting_enabled",
            "_call_reporting_enabled",
            b"_call_reporting_enabled",
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_reporting_enabled",
            b"call_conversion_reporting_enabled",
            "call_reporting_enabled",
            b"call_reporting_enabled",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_call_conversion_action",
            b"_call_conversion_action",
            "_call_conversion_reporting_enabled",
            b"_call_conversion_reporting_enabled",
            "_call_reporting_enabled",
            b"_call_reporting_enabled",
            "call_conversion_action",
            b"call_conversion_action",
            "call_conversion_reporting_enabled",
            b"call_conversion_reporting_enabled",
            "call_reporting_enabled",
            b"call_reporting_enabled",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_call_conversion_action", b"_call_conversion_action"
        ],
    ) -> typing_extensions___Literal["call_conversion_action"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_call_conversion_reporting_enabled", b"_call_conversion_reporting_enabled"
        ],
    ) -> typing_extensions___Literal["call_conversion_reporting_enabled"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_call_reporting_enabled", b"_call_reporting_enabled"
        ],
    ) -> typing_extensions___Literal["call_reporting_enabled"]: ...

type___CallReportingSetting = CallReportingSetting

class ConversionTrackingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    conversion_tracking_id: builtin___int = ...
    cross_account_conversion_tracking_id: builtin___int = ...
    def __init__(
        self,
        *,
        conversion_tracking_id: typing___Optional[builtin___int] = None,
        cross_account_conversion_tracking_id: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_conversion_tracking_id",
            b"_conversion_tracking_id",
            "_cross_account_conversion_tracking_id",
            b"_cross_account_conversion_tracking_id",
            "conversion_tracking_id",
            b"conversion_tracking_id",
            "cross_account_conversion_tracking_id",
            b"cross_account_conversion_tracking_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_conversion_tracking_id",
            b"_conversion_tracking_id",
            "_cross_account_conversion_tracking_id",
            b"_cross_account_conversion_tracking_id",
            "conversion_tracking_id",
            b"conversion_tracking_id",
            "cross_account_conversion_tracking_id",
            b"cross_account_conversion_tracking_id",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_tracking_id", b"_conversion_tracking_id"
        ],
    ) -> typing_extensions___Literal["conversion_tracking_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_cross_account_conversion_tracking_id",
            b"_cross_account_conversion_tracking_id",
        ],
    ) -> typing_extensions___Literal["cross_account_conversion_tracking_id"]: ...

type___ConversionTrackingSetting = ConversionTrackingSetting

class RemarketingSetting(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    google_global_site_tag: typing___Text = ...
    def __init__(
        self, *, google_global_site_tag: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_google_global_site_tag",
            b"_google_global_site_tag",
            "google_global_site_tag",
            b"google_global_site_tag",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_google_global_site_tag",
            b"_google_global_site_tag",
            "google_global_site_tag",
            b"google_global_site_tag",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_google_global_site_tag", b"_google_global_site_tag"
        ],
    ) -> typing_extensions___Literal["google_global_site_tag"]: ...

type___RemarketingSetting = RemarketingSetting



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.common.dates_pb2 import (
    DateRange as google___ads___googleads___v4___common___dates_pb2___DateRange,
)
from google.ads.google_ads.v4.proto.enums.invoice_type_pb2 import (
    InvoiceTypeEnum as google___ads___googleads___v4___enums___invoice_type_pb2___InvoiceTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Invoice(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AccountBudgetSummary(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def customer(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def customer_descriptive_name(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def account_budget(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def account_budget_name(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def purchase_order_number(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def subtotal_amount_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def tax_amount_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def total_amount_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def billable_activity_date_range(
            self,
        ) -> google___ads___googleads___v4___common___dates_pb2___DateRange: ...
        def __init__(
            self,
            *,
            customer: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            customer_descriptive_name: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            account_budget: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            account_budget_name: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            purchase_order_number: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            subtotal_amount_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            tax_amount_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            total_amount_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            billable_activity_date_range: typing___Optional[
                google___ads___googleads___v4___common___dates_pb2___DateRange
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "account_budget",
                b"account_budget",
                "account_budget_name",
                b"account_budget_name",
                "billable_activity_date_range",
                b"billable_activity_date_range",
                "customer",
                b"customer",
                "customer_descriptive_name",
                b"customer_descriptive_name",
                "purchase_order_number",
                b"purchase_order_number",
                "subtotal_amount_micros",
                b"subtotal_amount_micros",
                "tax_amount_micros",
                b"tax_amount_micros",
                "total_amount_micros",
                b"total_amount_micros",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "account_budget",
                b"account_budget",
                "account_budget_name",
                b"account_budget_name",
                "billable_activity_date_range",
                b"billable_activity_date_range",
                "customer",
                b"customer",
                "customer_descriptive_name",
                b"customer_descriptive_name",
                "purchase_order_number",
                b"purchase_order_number",
                "subtotal_amount_micros",
                b"subtotal_amount_micros",
                "tax_amount_micros",
                b"tax_amount_micros",
                "total_amount_micros",
                b"total_amount_micros",
            ],
        ) -> None: ...
    type___AccountBudgetSummary = AccountBudgetSummary

    resource_name: typing___Text = ...
    type: google___ads___googleads___v4___enums___invoice_type_pb2___InvoiceTypeEnum.InvoiceTypeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def billing_setup(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def payments_account_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def payments_profile_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def issue_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def due_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def service_date_range(
        self,
    ) -> google___ads___googleads___v4___common___dates_pb2___DateRange: ...
    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def invoice_level_adjustments_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def subtotal_amount_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def tax_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def total_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def corrected_invoice(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def replaced_invoices(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def pdf_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def account_budget_summaries(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___Invoice.AccountBudgetSummary
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        type: typing___Optional[
            google___ads___googleads___v4___enums___invoice_type_pb2___InvoiceTypeEnum.InvoiceTypeValue
        ] = None,
        billing_setup: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        payments_account_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        payments_profile_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        issue_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        due_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        service_date_range: typing___Optional[
            google___ads___googleads___v4___common___dates_pb2___DateRange
        ] = None,
        currency_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        invoice_level_adjustments_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        subtotal_amount_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        tax_amount_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        total_amount_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        corrected_invoice: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        replaced_invoices: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        pdf_url: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        account_budget_summaries: typing___Optional[
            typing___Iterable[type___Invoice.AccountBudgetSummary]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "billing_setup",
            b"billing_setup",
            "corrected_invoice",
            b"corrected_invoice",
            "currency_code",
            b"currency_code",
            "due_date",
            b"due_date",
            "id",
            b"id",
            "invoice_level_adjustments_micros",
            b"invoice_level_adjustments_micros",
            "issue_date",
            b"issue_date",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "pdf_url",
            b"pdf_url",
            "service_date_range",
            b"service_date_range",
            "subtotal_amount_micros",
            b"subtotal_amount_micros",
            "tax_amount_micros",
            b"tax_amount_micros",
            "total_amount_micros",
            b"total_amount_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "account_budget_summaries",
            b"account_budget_summaries",
            "billing_setup",
            b"billing_setup",
            "corrected_invoice",
            b"corrected_invoice",
            "currency_code",
            b"currency_code",
            "due_date",
            b"due_date",
            "id",
            b"id",
            "invoice_level_adjustments_micros",
            b"invoice_level_adjustments_micros",
            "issue_date",
            b"issue_date",
            "payments_account_id",
            b"payments_account_id",
            "payments_profile_id",
            b"payments_profile_id",
            "pdf_url",
            b"pdf_url",
            "replaced_invoices",
            b"replaced_invoices",
            "resource_name",
            b"resource_name",
            "service_date_range",
            b"service_date_range",
            "subtotal_amount_micros",
            b"subtotal_amount_micros",
            "tax_amount_micros",
            b"tax_amount_micros",
            "total_amount_micros",
            b"total_amount_micros",
            "type",
            b"type",
        ],
    ) -> None: ...

type___Invoice = Invoice



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.mobile_device_type_pb2 import (
    MobileDeviceTypeEnum as google___ads___googleads___v6___enums___mobile_device_type_pb2___MobileDeviceTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MobileDeviceConstant(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    name: typing___Text = ...
    manufacturer_name: typing___Text = ...
    operating_system_name: typing___Text = ...
    type: google___ads___googleads___v6___enums___mobile_device_type_pb2___MobileDeviceTypeEnum.MobileDeviceTypeValue = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        name: typing___Optional[typing___Text] = None,
        manufacturer_name: typing___Optional[typing___Text] = None,
        operating_system_name: typing___Optional[typing___Text] = None,
        type: typing___Optional[
            google___ads___googleads___v6___enums___mobile_device_type_pb2___MobileDeviceTypeEnum.MobileDeviceTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_manufacturer_name",
            b"_manufacturer_name",
            "_name",
            b"_name",
            "_operating_system_name",
            b"_operating_system_name",
            "id",
            b"id",
            "manufacturer_name",
            b"manufacturer_name",
            "name",
            b"name",
            "operating_system_name",
            b"operating_system_name",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_manufacturer_name",
            b"_manufacturer_name",
            "_name",
            b"_name",
            "_operating_system_name",
            b"_operating_system_name",
            "id",
            b"id",
            "manufacturer_name",
            b"manufacturer_name",
            "name",
            b"name",
            "operating_system_name",
            b"operating_system_name",
            "resource_name",
            b"resource_name",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_manufacturer_name", b"_manufacturer_name"
        ],
    ) -> typing_extensions___Literal["manufacturer_name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_operating_system_name", b"_operating_system_name"
        ],
    ) -> typing_extensions___Literal["operating_system_name"]: ...

type___MobileDeviceConstant = MobileDeviceConstant



from typing import Any

class DisplayKeywordViewServiceStub:
    GetDisplayKeywordView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class DisplayKeywordViewServiceServicer:
    def GetDisplayKeywordView(self, request: Any, context: Any) -> None: ...

def add_DisplayKeywordViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any

class CurrencyConstantServiceStub:
    GetCurrencyConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CurrencyConstantServiceServicer:
    def GetCurrencyConstant(self, request: Any, context: Any) -> None: ...

def add_CurrencyConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UserListSizeRangeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    UserListSizeRangeValue = typing___NewType("UserListSizeRangeValue", builtin___int)
    type___UserListSizeRangeValue = UserListSizeRangeValue
    UserListSizeRange: _UserListSizeRange
    class _UserListSizeRange(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            UserListSizeRangeEnum.UserListSizeRangeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 0)
        UNKNOWN = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 1)
        LESS_THAN_FIVE_HUNDRED = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 2
        )
        LESS_THAN_ONE_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 3
        )
        ONE_THOUSAND_TO_TEN_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 4
        )
        TEN_THOUSAND_TO_FIFTY_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 5
        )
        FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 6
        )
        ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 7
        )
        THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 8
        )
        FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 9
        )
        ONE_MILLION_TO_TWO_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 10
        )
        TWO_MILLION_TO_THREE_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 11
        )
        THREE_MILLION_TO_FIVE_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 12
        )
        FIVE_MILLION_TO_TEN_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 13
        )
        TEN_MILLION_TO_TWENTY_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 14
        )
        TWENTY_MILLION_TO_THIRTY_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 15
        )
        THIRTY_MILLION_TO_FIFTY_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 16
        )
        OVER_FIFTY_MILLION = typing___cast(
            UserListSizeRangeEnum.UserListSizeRangeValue, 17
        )
    UNSPECIFIED = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 0)
    UNKNOWN = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 1)
    LESS_THAN_FIVE_HUNDRED = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 2
    )
    LESS_THAN_ONE_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 3
    )
    ONE_THOUSAND_TO_TEN_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 4
    )
    TEN_THOUSAND_TO_FIFTY_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 5
    )
    FIFTY_THOUSAND_TO_ONE_HUNDRED_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 6
    )
    ONE_HUNDRED_THOUSAND_TO_THREE_HUNDRED_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 7
    )
    THREE_HUNDRED_THOUSAND_TO_FIVE_HUNDRED_THOUSAND = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 8
    )
    FIVE_HUNDRED_THOUSAND_TO_ONE_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 9
    )
    ONE_MILLION_TO_TWO_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 10
    )
    TWO_MILLION_TO_THREE_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 11
    )
    THREE_MILLION_TO_FIVE_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 12
    )
    FIVE_MILLION_TO_TEN_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 13
    )
    TEN_MILLION_TO_TWENTY_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 14
    )
    TWENTY_MILLION_TO_THIRTY_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 15
    )
    THIRTY_MILLION_TO_FIFTY_MILLION = typing___cast(
        UserListSizeRangeEnum.UserListSizeRangeValue, 16
    )
    OVER_FIFTY_MILLION = typing___cast(UserListSizeRangeEnum.UserListSizeRangeValue, 17)
    type___UserListSizeRange = UserListSizeRange
    def __init__(self,) -> None: ...

type___UserListSizeRangeEnum = UserListSizeRangeEnum



from typing import Any

class CampaignServiceStub:
    GetCampaign: Any = ...
    MutateCampaigns: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CampaignServiceServicer:
    def GetCampaign(self, request: Any, context: Any) -> None: ...
    def MutateCampaigns(self, request: Any, context: Any) -> None: ...

def add_CampaignServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.rpc.status_pb2 import Status as google___rpc___status_pb2___Status
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.resources.batch_job_pb2 import (
    BatchJob as google___ads___googleads___v6___resources___batch_job_pb2___BatchJob,
)
from google.ads.google_ads.v6.proto.services.google_ads_service_pb2 import (
    MutateOperation as google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperation,
    MutateOperationResponse as google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperationResponse,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MutateBatchJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    @property
    def operation(self) -> type___BatchJobOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operation: typing___Optional[type___BatchJobOperation] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["operation", b"operation"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id", b"customer_id", "operation", b"operation"
        ],
    ) -> None: ...

type___MutateBatchJobRequest = MutateBatchJobRequest

class BatchJobOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def create(
        self,
    ) -> google___ads___googleads___v6___resources___batch_job_pb2___BatchJob: ...
    def __init__(
        self,
        *,
        create: typing___Optional[
            google___ads___googleads___v6___resources___batch_job_pb2___BatchJob
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["operation", b"operation"]
    ) -> typing_extensions___Literal["create"]: ...

type___BatchJobOperation = BatchJobOperation

class MutateBatchJobResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def result(self) -> type___MutateBatchJobResult: ...
    def __init__(
        self, *, result: typing___Optional[type___MutateBatchJobResult] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> builtin___bool: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["result", b"result"]
    ) -> None: ...

type___MutateBatchJobResponse = MutateBatchJobResponse

class MutateBatchJobResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___MutateBatchJobResult = MutateBatchJobResult

class GetBatchJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetBatchJobRequest = GetBatchJobRequest

class RunBatchJobRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___RunBatchJobRequest = RunBatchJobRequest

class AddBatchJobOperationsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    sequence_token: typing___Text = ...
    @property
    def mutate_operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperation
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        sequence_token: typing___Optional[typing___Text] = None,
        mutate_operations: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperation
            ]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "mutate_operations",
            b"mutate_operations",
            "resource_name",
            b"resource_name",
            "sequence_token",
            b"sequence_token",
        ],
    ) -> None: ...

type___AddBatchJobOperationsRequest = AddBatchJobOperationsRequest

class AddBatchJobOperationsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    total_operations: builtin___int = ...
    next_sequence_token: typing___Text = ...
    def __init__(
        self,
        *,
        total_operations: typing___Optional[builtin___int] = None,
        next_sequence_token: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "next_sequence_token",
            b"next_sequence_token",
            "total_operations",
            b"total_operations",
        ],
    ) -> None: ...

type___AddBatchJobOperationsResponse = AddBatchJobOperationsResponse

class ListBatchJobResultsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    page_token: typing___Text = ...
    page_size: builtin___int = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        page_token: typing___Optional[typing___Text] = None,
        page_size: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "page_size",
            b"page_size",
            "page_token",
            b"page_token",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

type___ListBatchJobResultsRequest = ListBatchJobResultsRequest

class ListBatchJobResultsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token: typing___Text = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___BatchJobResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing___Optional[typing___Iterable[type___BatchJobResult]] = None,
        next_page_token: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "next_page_token", b"next_page_token", "results", b"results"
        ],
    ) -> None: ...

type___ListBatchJobResultsResponse = ListBatchJobResultsResponse

class BatchJobResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operation_index: builtin___int = ...
    @property
    def mutate_operation_response(
        self,
    ) -> google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperationResponse: ...
    @property
    def status(self) -> google___rpc___status_pb2___Status: ...
    def __init__(
        self,
        *,
        operation_index: typing___Optional[builtin___int] = None,
        mutate_operation_response: typing___Optional[
            google___ads___googleads___v6___services___google_ads_service_pb2___MutateOperationResponse
        ] = None,
        status: typing___Optional[google___rpc___status_pb2___Status] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "mutate_operation_response",
            b"mutate_operation_response",
            "status",
            b"status",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "mutate_operation_response",
            b"mutate_operation_response",
            "operation_index",
            b"operation_index",
            "status",
            b"status",
        ],
    ) -> None: ...

type___BatchJobResult = BatchJobResult
